.. _homogenization-linear_elasticity_opt:

homogenization/linear_elasticity_opt.py
=======================================

**Description**

missing description!



:download:`source code </../sfepy/examples/homogenization/linear_elasticity_opt.py>`

.. literalinclude:: /../sfepy/examples/homogenization/linear_elasticity_opt.py

